@@ -1,9 +1,10 @@
 import pandas
+import deprecation
 
 from pm4py import util as pmutil
 from pm4py.algo.discovery.alpha import versions
 from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
-from pm4py.objects.conversion.log import factory as log_conversion
+from pm4py.objects.conversion.log import converter as log_conversion
 from pm4py.util import xes_constants as xes_util
 
 ALPHA_VERSION_CLASSIC = 'classic'
@@ -14,7 +15,8 @@ VERSIONS_DFG = {ALPHA_VERSION_CLASSIC: versions.classic.apply_dfg}
 
 DEFAULT_PARAMETERS = {pmutil.constants.PARAMETER_CONSTANT_ACTIVITY_KEY: xes_util.DEFAULT_NAME_KEY}
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use algorithm entrypoint instead')
 def apply(log, parameters=None, variant=ALPHA_VERSION_CLASSIC):
     """
     Apply the Alpha Miner on top of a log
@@ -54,7 +56,9 @@ def apply(log, parameters=None, variant=ALPHA_VERSION_CLASSIC):
     return VERSIONS[variant](log_conversion.apply(log, parameters, log_conversion.TO_EVENT_LOG), parameters)
 
 
-def apply_dfg(dfg, parameters=None, version=ALPHA_VERSION_CLASSIC):
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use algorithm entrypoint instead')
+def apply_dfg(dfg, parameters=None, variant=ALPHA_VERSION_CLASSIC):
     """
     Apply Alpha Miner directly on top of a DFG graph
 
@@ -62,7 +66,7 @@ def apply_dfg(dfg, parameters=None, version=ALPHA_VERSION_CLASSIC):
     -----------
     dfg
         Directly-Follows graph
-    version
+    variant
         Variant of the algorithm to use (classic)
     parameters
         Possible parameters of the algorithm, including:
@@ -81,4 +85,5 @@ def apply_dfg(dfg, parameters=None, version=ALPHA_VERSION_CLASSIC):
         parameters = {}
     if pmutil.constants.PARAMETER_CONSTANT_ACTIVITY_KEY not in parameters:
         parameters[pmutil.constants.PARAMETER_CONSTANT_ACTIVITY_KEY] = xes_util.DEFAULT_NAME_KEY
-    return VERSIONS_DFG[version](dfg, parameters)
+    return VERSIONS_DFG[variant](dfg, parameters)
+
