@@ -1,5 +1,4 @@
-import networkx as nx
-import numpy as np
+import numpy as np, pkgutil, logging
 
 from copy import copy
 
@@ -569,14 +568,21 @@ class SubtreeDFGBased():
         nodes_map
             Correspondence between digraph nodes and activities
         """
-        G = nx.DiGraph()
-        for act in self.activities:
-            G.add_node(act)
-        for el in self.dfg:
-            act1 = el[0][0]
-            act2 = el[0][1]
-            G.add_edge(act1, act2)
-        return G
+        if pkgutil.find_loader("networkx"):
+            import networkx as nx
+
+            G = nx.DiGraph()
+            for act in self.activities:
+                G.add_node(act)
+            for el in self.dfg:
+                act1 = el[0][0]
+                act2 = el[0][1]
+                G.add_edge(act1, act2)
+            return G
+        else:
+            msg = "networkx is not available. inductive miner cannot be used!"
+            logging.error(msg)
+            raise Exception(msg)
 
     def put_skips_in_seq_cut(self):
         """
@@ -658,6 +664,13 @@ class SubtreeDFGBased():
         """
         Detect generally a cut in the graph (applying all the algorithms)
         """
+        if pkgutil.find_loader("networkx"):
+            import networkx as nx
+        else:
+            msg = "networkx is not available. inductive miner cannot be used!"
+            logging.error(msg)
+            raise Exception(msg)
+
         if self.dfg:
             # print("\n\n")
             conn_components = self.get_connected_components(self.ingoing, self.outgoing, self.activities)
