@@ -1,2 +1,2 @@
 from pm4py.algo.filtering.log import attributes, auto_filter, end_activities, paths, \
-    cases, start_activities, timestamp, variants
+    cases, start_activities, timestamp, variants, ltl
