@@ -1,16 +1,15 @@
 from copy import deepcopy
 
-import networkx as nx
 import numpy as np
 
 from pm4py.objects.petri import incidence_matrix
 from pm4py.objects.petri import utils as petri_utils
 from pm4py.objects.petri import petrinet
 from pm4py.objects.petri.networkx_graph import create_networkx_undirected_graph
-from pm4py.util.lp import factory as lp_solver_factory
+from pm4py.util.lp import solver as lp_solver
 from pm4py.objects.petri import explore_path
 
-DEFAULT_LP_SOLVER_VARIANT = lp_solver_factory.PULP
+DEFAULT_LP_SOLVER_VARIANT = lp_solver.PULP
 
 
 def check_source_and_sink_reachability(net, unique_source, unique_sink):
@@ -32,6 +31,8 @@ def check_source_and_sink_reachability(net, unique_source, unique_sink):
     boolean
         Boolean value that is true if each node is in a path from the source place to the sink place
     """
+    import networkx as nx
+
     graph, unique_source_corr, unique_sink_corr, inv_dictionary = create_networkx_undirected_graph(net, unique_source,
                                                                                                    unique_sink)
     if unique_source_corr is not None and unique_sink_corr is not None:
@@ -128,6 +129,8 @@ def check_loops_generating_tokens(net0):
     boolean
         Boolean value (True if the net has loops generating tokens)
     """
+    import networkx as nx
+
     net = deepcopy(net0)
     petri_utils.decorate_transitions_prepostset(net)
     graph, inv_dictionary = petri_utils.create_networkx_directed_graph(net)
@@ -201,6 +204,8 @@ def check_non_blocking(net0):
     boolean
         Boolean value
     """
+    import networkx as nx
+
     net = deepcopy(net0)
     petri_utils.decorate_transitions_prepostset(net)
     graph, inv_dictionary = petri_utils.create_networkx_directed_graph(net)
@@ -274,7 +279,7 @@ def check_stability_wfnet(net):
         i = i + 1
 
     try:
-        sol = lp_solver_factory.apply(c, vstack_matrix, bub, None, None, variant=DEFAULT_LP_SOLVER_VARIANT)
+        sol = lp_solver.apply(c, vstack_matrix, bub, None, None, variant=DEFAULT_LP_SOLVER_VARIANT)
         if sol:
             return True
     except:
