@@ -17,3 +17,7 @@ CASE_ATTRIBUTE_PREFIX = 'case:'
 
 PARAMETER_KEY_CASE_GLUE = 'case_id_glue'
 PARAMETER_KEY_CASE_ATTRIBUTE_PRFIX = 'case:'
+
+STOCHASTIC_DISTRIBUTION = "stochastic_distribution"
+LAYOUT_INFORMATION_PETRI = "layout_information_petri"
+PLACE_NAME_TAG = "place_name_tag"
